==> estateplat-common-1.2.3-20180116.075332-15-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxQctbSqrxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-1-12
 * @description 全城通办权利人
 */
@Entity
@Table(name = "gx_qctb_sqrxx")
public class GxQctbSqrxx {
    @Id
    private String sqrxxid;//申请人信息ID(主键)
    private String xmid;//项目ID
    private String sqrmc;//申请人名称
    private String sqrsfzjzl;//申请人身份证件种类(证件种类字典表)
    private String sqrzjh;//申请人证件号
    private String sqrtxdz;//申请人通讯地址
    private String sqryb;//申请人邮编
    private String sqrfddbr;//申请人法定代表人
    private String sqrfddbrdh;//申请人法定代表人电话
    private String sqrdlr;//申请人代理人
    private String sqrdlrdh;//申请人代理人电话
    private String sqrdljg;//申请人代理机构
    private String sqrlx;//申请人类型(申请人类型字典表)
    private String qlbl;//权利比例
    private String gyfs;//共有方式(共有方式字典表)
    private String gyqk;//共有情况(共有情况字典表)
    private String sqrxz;//申请人性质(权利人类型字典表)
    private String sqrlxdh;//申请人联系电话
    private String sshy;//所属行业
    private String bz;//备注
    private String sfczr;//是否持证人(是否字典表)
    private Double sxh;//顺序号
    private String sfxs;//是否显示(是否字典表)
    private String sqrfddbrzjzl;//申请人法定代表人证件种类(申请人法定代表人证件种类)
    private String sqrfddbrzjh;//申请人法定代表人证件号
    private String sqrdlrzjzl;//申请人代理人证件种类(申请人法定代表人证件种类)
    private String sqrdlrzjh;//申请人代理人证件号
    private String xb;//性别
    private Double qlmj;//权利面积
    private String qygyr;//其余共有人
    private String txfs;//填写方式(填写方式字典表)

    public String getSqrxxid() {
        return sqrxxid;
    }

    public void setSqrxxid(String sqrxxid) {
        this.sqrxxid = sqrxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getSqrsfzjzl() {
        return sqrsfzjzl;
    }

    public void setSqrsfzjzl(String sqrsfzjzl) {
        this.sqrsfzjzl = sqrsfzjzl;
    }

    public String getSqrzjh() {
        return sqrzjh;
    }

    public void setSqrzjh(String sqrzjh) {
        this.sqrzjh = sqrzjh;
    }

    public String getSqrtxdz() {
        return sqrtxdz;
    }

    public void setSqrtxdz(String sqrtxdz) {
        this.sqrtxdz = sqrtxdz;
    }

    public String getSqryb() {
        return sqryb;
    }

    public void setSqryb(String sqryb) {
        this.sqryb = sqryb;
    }

    public String getSqrfddbr() {
        return sqrfddbr;
    }

    public void setSqrfddbr(String sqrfddbr) {
        this.sqrfddbr = sqrfddbr;
    }

    public String getSqrfddbrdh() {
        return sqrfddbrdh;
    }

    public void setSqrfddbrdh(String sqrfddbrdh) {
        this.sqrfddbrdh = sqrfddbrdh;
    }

    public String getSqrdlr() {
        return sqrdlr;
    }

    public void setSqrdlr(String sqrdlr) {
        this.sqrdlr = sqrdlr;
    }

    public String getSqrdlrdh() {
        return sqrdlrdh;
    }

    public void setSqrdlrdh(String sqrdlrdh) {
        this.sqrdlrdh = sqrdlrdh;
    }

    public String getSqrdljg() {
        return sqrdljg;
    }

    public void setSqrdljg(String sqrdljg) {
        this.sqrdljg = sqrdljg;
    }

    public String getSqrlx() {
        return sqrlx;
    }

    public void setSqrlx(String sqrlx) {
        this.sqrlx = sqrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getSqrxz() {
        return sqrxz;
    }

    public void setSqrxz(String sqrxz) {
        this.sqrxz = sqrxz;
    }

    public String getSqrlxdh() {
        return sqrlxdh;
    }

    public void setSqrlxdh(String sqrlxdh) {
        this.sqrlxdh = sqrlxdh;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public Double getSxh() {
        return sxh;
    }

    public void setSxh(Double sxh) {
        this.sxh = sxh;
    }

    public String getSfxs() {
        return sfxs;
    }

    public void setSfxs(String sfxs) {
        this.sfxs = sfxs;
    }

    public String getSqrfddbrzjzl() {
        return sqrfddbrzjzl;
    }

    public void setSqrfddbrzjzl(String sqrfddbrzjzl) {
        this.sqrfddbrzjzl = sqrfddbrzjzl;
    }

    public String getSqrfddbrzjh() {
        return sqrfddbrzjh;
    }

    public void setSqrfddbrzjh(String sqrfddbrzjh) {
        this.sqrfddbrzjh = sqrfddbrzjh;
    }

    public String getSqrdlrzjzl() {
        return sqrdlrzjzl;
    }

    public void setSqrdlrzjzl(String sqrdlrzjzl) {
        this.sqrdlrzjzl = sqrdlrzjzl;
    }

    public String getSqrdlrzjh() {
        return sqrdlrzjh;
    }

    public void setSqrdlrzjh(String sqrdlrzjh) {
        this.sqrdlrzjh = sqrdlrzjh;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public Double getQlmj() {
        return qlmj;
    }

    public void setQlmj(Double qlmj) {
        this.qlmj = qlmj;
    }

    public String getQygyr() {
        return qygyr;
    }

    public void setQygyr(String qygyr) {
        this.qygyr = qygyr;
    }

    public String getTxfs() {
        return txfs;
    }

    public void setTxfs(String txfs) {
        this.txfs = txfs;
    }
}

==> estateplat-common-1.2.4-20220329.072424-992-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxQctbSqrxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlType;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-1-12
 * @description 全城通办权利人
 */
@Entity
@Table(name = "gx_qctb_sqrxx")
public class GxQctbSqrxx {
    @Id
    private String sqrxxid;//申请人信息ID(主键)
    private String xmid;//项目ID
    private String sqrmc;//申请人名称
    private String sqrsfzjzl;//申请人身份证件种类(证件种类字典表)
    private String sqrzjh;//申请人证件号
    private String sqrtxdz;//申请人通讯地址
    private String sqryb;//申请人邮编
    private String sqrfddbr;//申请人法定代表人
    private String sqrfddbrdh;//申请人法定代表人电话
    private String sqrdlr;//申请人代理人
    private String sqrdlrdh;//申请人代理人电话
    private String sqrdljg;//申请人代理机构
    private String sqrlx;//申请人类型(申请人类型字典表)
    private String qlbl;//权利比例
    private String gyfs;//共有方式(共有方式字典表)
    private String gyqk;//共有情况(共有情况字典表)
    private String sqrxz;//申请人性质(权利人类型字典表)
    private String sqrlxdh;//申请人联系电话
    private String sshy;//所属行业
    private String bz;//备注
    private String sfczr;//是否持证人(是否字典表)
    private Integer sxh;//顺序号
    private String sfxs;//是否显示(是否字典表)
    private String sqrfddbrzjzl;//申请人法定代表人证件种类(申请人法定代表人证件种类)
    private String sqrfddbrzjh;//申请人法定代表人证件号
    private String sqrdlrzjzl;//申请人代理人证件种类(申请人法定代表人证件种类)
    private String sqrdlrzjh;//申请人代理人证件号
    private String xb;//性别
    private Double qlmj;//权利面积
    private String qygyr;//其余共有人
    private String txfs;//填写方式(填写方式字典表)

    public String getSqrxxid() {
        return sqrxxid;
    }

    public void setSqrxxid(String sqrxxid) {
        this.sqrxxid = sqrxxid;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getSqrmc() {
        return sqrmc;
    }

    public void setSqrmc(String sqrmc) {
        this.sqrmc = sqrmc;
    }

    public String getSqrsfzjzl() {
        return sqrsfzjzl;
    }

    public void setSqrsfzjzl(String sqrsfzjzl) {
        this.sqrsfzjzl = sqrsfzjzl;
    }

    public String getSqrzjh() {
        return sqrzjh;
    }

    public void setSqrzjh(String sqrzjh) {
        this.sqrzjh = sqrzjh;
    }

    public String getSqrtxdz() {
        return sqrtxdz;
    }

    public void setSqrtxdz(String sqrtxdz) {
        this.sqrtxdz = sqrtxdz;
    }

    public String getSqryb() {
        return sqryb;
    }

    public void setSqryb(String sqryb) {
        this.sqryb = sqryb;
    }

    public String getSqrfddbr() {
        return sqrfddbr;
    }

    public void setSqrfddbr(String sqrfddbr) {
        this.sqrfddbr = sqrfddbr;
    }

    public String getSqrfddbrdh() {
        return sqrfddbrdh;
    }

    public void setSqrfddbrdh(String sqrfddbrdh) {
        this.sqrfddbrdh = sqrfddbrdh;
    }

    public String getSqrdlr() {
        return sqrdlr;
    }

    public void setSqrdlr(String sqrdlr) {
        this.sqrdlr = sqrdlr;
    }

    public String getSqrdlrdh() {
        return sqrdlrdh;
    }

    public void setSqrdlrdh(String sqrdlrdh) {
        this.sqrdlrdh = sqrdlrdh;
    }

    public String getSqrdljg() {
        return sqrdljg;
    }

    public void setSqrdljg(String sqrdljg) {
        this.sqrdljg = sqrdljg;
    }

    public String getSqrlx() {
        return sqrlx;
    }

    public void setSqrlx(String sqrlx) {
        this.sqrlx = sqrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getSqrxz() {
        return sqrxz;
    }

    public void setSqrxz(String sqrxz) {
        this.sqrxz = sqrxz;
    }

    public String getSqrlxdh() {
        return sqrlxdh;
    }

    public void setSqrlxdh(String sqrlxdh) {
        this.sqrlxdh = sqrlxdh;
    }

    public String getSshy() {
        return sshy;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSfczr() {
        return sfczr;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }

    public String getSfxs() {
        return sfxs;
    }

    public void setSfxs(String sfxs) {
        this.sfxs = sfxs;
    }

    public String getSqrfddbrzjzl() {
        return sqrfddbrzjzl;
    }

    public void setSqrfddbrzjzl(String sqrfddbrzjzl) {
        this.sqrfddbrzjzl = sqrfddbrzjzl;
    }

    public String getSqrfddbrzjh() {
        return sqrfddbrzjh;
    }

    public void setSqrfddbrzjh(String sqrfddbrzjh) {
        this.sqrfddbrzjh = sqrfddbrzjh;
    }

    public String getSqrdlrzjzl() {
        return sqrdlrzjzl;
    }

    public void setSqrdlrzjzl(String sqrdlrzjzl) {
        this.sqrdlrzjzl = sqrdlrzjzl;
    }

    public String getSqrdlrzjh() {
        return sqrdlrzjh;
    }

    public void setSqrdlrzjh(String sqrdlrzjh) {
        this.sqrdlrzjh = sqrdlrzjh;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public Double getQlmj() {
        return qlmj;
    }

    public void setQlmj(Double qlmj) {
        this.qlmj = qlmj;
    }

    public String getQygyr() {
        return qygyr;
    }

    public void setQygyr(String qygyr) {
        this.qygyr = qygyr;
    }

    public String getTxfs() {
        return txfs;
    }

    public void setTxfs(String txfs) {
        this.txfs = txfs;
    }
}
